@@ -12,8 +12,11 @@ from __future__ import unicode_literals, absolute_import, print_function, divisi
 #                                                                       #
 #########################################################################
 import sys, os, re
+
 from calibre.ebooks.rtf2xml import copy
 from calibre.ptempfile import better_mktemp
+from polyglot.builtins import unicode_type
+
 from . import open_for_read, open_for_write
 
 
@@ -287,7 +290,7 @@ class MakeLists:
             'mi<mk<list_start\n'
                 )
         # bogus levels are sometimes written for empty paragraphs
-        if str(self.__level) not in self.__allow_levels:
+        if unicode_type(self.__level) not in self.__allow_levels:
             lev_num = '0'
         else:
             lev_num = self.__level
